# Contributor License Agreement (CLA)

Thank you for your interest in contributing to this project.

By submitting a pull request or otherwise contributing to this repository, you agree to the following terms:

1. You grant the project owner a perpetual, worldwide, non-exclusive, royalty-free, irrevocable license to use, reproduce, modify, distribute, and sublicense your contributions as part of the project.
2. You confirm that each of your contributions is an original work and that you have the right to grant such a license.
3. You acknowledge that your contributions are provided voluntarily and that you are not entitled to any compensation or reimbursement for your contributions.

Please sign this CLA by submitting a pull request with the following line in your pull request description or a comment:

"I have read and agree to the Contributor License Agreement."

Thank you for your contributions!
